@@ -17,9 +17,10 @@ class RiffMetadata(MultipleMetadata):
         "IART": "artist",
         "ICMT": "comment",
         "ICOP": "copyright",
-        "IENG": "author",
+        "IENG": "author",    # (engineer)
         "ISFT": "producer",
         "ICRD": "creation_date",
+        "IDIT": "creation_date",
     }
 
     def extract(self, riff):
@@ -32,6 +33,7 @@ class RiffMetadata(MultipleMetadata):
         elif type == "AVI ":
             if "headers" in riff:
                 self.extractAVI(riff["headers"])
+                self.extractInfo(riff["headers"])
         elif type == "ACON":
             self.extractAnim(riff)
         if "info" in riff:
@@ -104,6 +106,8 @@ class RiffMetadata(MultipleMetadata):
         meta.nb_channel = format["channel"].value
         meta.sample_rate = format["sample_rate"].value
         meta.bit_rate = format["bit_rate"].value * 8
+        if format["bits_per_sample"].value:
+            meta.bits_per_sample = format["bits_per_sample"].value
         if "../stream_hdr" in format:
             header = format["../stream_hdr"]
             if header["rate"].value and header["scale"].value:
@@ -115,6 +119,18 @@ class RiffMetadata(MultipleMetadata):
         if not meta.has("compression"):
             meta.compression = format["codec"].display
 
+        self.computeAudioComprRate(meta)
+
+    @fault_tolerant
+    def computeAudioComprRate(self, meta):
+        uncompr = meta.get('bit_rate', 0)
+        if not uncompr:
+            return
+        compr = meta.get('nb_channel') * meta.get('sample_rate') * meta.get('bits_per_sample', default=16)
+        if not compr:
+            return
+        meta.compr_rate = float(compr) / uncompr
+
     @fault_tolerant
     def useAviHeader(self, header):
         microsec = header["microsec_per_frame"].value
